@@ -36,12 +36,16 @@ class SCMProcessor(BaseProcessor):
         if '.git.receive' in msg['topic']:
             query_string = urllib.urlencode({
                 's': 64,
-                'd': "https://apps.fedoraproject.org/img/icons/git-logo.png",
+                'd': 'http://fedoraproject.org/static/images/'
+                'fedora_infinity_64x64.png',
             })
             email = msg['msg']['commit']['email']
             hash = md5(email).hexdigest()
             tmpl = "http://www.gravatar.com/avatar/%s?%s"
             return tmpl % (hash, query_string)
+        elif '.git.lookaside' in msg['topic']:
+            username = msg['msg']['agent']
+            return gravatar_url(username)
 
     def subtitle(self, msg, **config):
         if '.git.receive' in msg['topic']:
