@@ -39,9 +39,10 @@ class TestAskbotRetag(Base):
     expected_title = "askbot.tag.update"
     expected_subti = "ralph altered tags on askbot question 'some title'"
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
-    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
-                              "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-                              "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -88,9 +89,10 @@ class TestAskbotNewQuestion(Base):
     expected_title = "askbot.post.edit"
     expected_subti = "ralph asked the question 'I have a new question'"
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
-    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
-                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -143,9 +145,10 @@ class TestAskbotNewAnswer(Base):
     expected_subti = ("ralph suggested an answer "
                       "to the question 'watwatwatwata'")
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
-    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
-                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph', 'lmacken'])
     expected_objects = set([
@@ -196,9 +199,10 @@ class TestAskbotFlagOffensiveAdd(Base):
     expected_title = "askbot.post.flag_offensive.add"
     expected_subti = "ralph flagged a question as offensive!"
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
-    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
-                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -246,9 +250,10 @@ class TestAskbotFlagOffensiveRemove(Base):
     expected_title = "askbot.post.flag_offensive.delete"
     expected_subti = "ralph unflagged an answer as offensive..."
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
-    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
-                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -297,9 +302,10 @@ class TestAskbotUpdatedQuestion(Base):
     expected_title = "askbot.post.edit"
     expected_subti = "ralph updated the question 'alskdjflaksjdf lakjsf a'"
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
-    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
-                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_emails = {'ralph@fedoraproject.org': 'ralph'}
@@ -353,9 +359,10 @@ class TestAskbotUpdatedAnswer(Base):
     expected_subti = ("ralph updated an answer "
                       "to the question 'I have a new question'")
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
-    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
-                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -405,9 +412,10 @@ class TestAskbotAnswerDeleted(Base):
     expected_title = "askbot.post.delete"
     expected_subti = "ralph deleted an answer on 'test 3 is a charm'"
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
-    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
-                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -451,9 +459,10 @@ class TestAskbotQuestionDeleted(Base):
     expected_title = "askbot.post.delete"
     expected_subti = "ralph deleted the question 'test 3 is a charm'"
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
-    expected_secondary_icon = ("http://www.gravatar.com/avatar/"
-                               "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-                               "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+    expected_secondary_icon = (
+        "http://www.gravatar.com/avatar/"
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
